
# INTERMEDIATE R SCRIPT 

# Date: 11/2/2020
# Authors: Bethany King and Rohini Ghosh

#clears memory and workspace
rm(list = ls())

#set working directory
setwd("C:/Users/ro_12/Desktop/Intermediate R Lecture")

# First, load dataset
wy_data<-read.csv("int_dataset.csv", skip=1, header=TRUE, 
                  na.strings=c("","NA"), stringsAsFactors = FALSE)

# Take a look at the dataset and we'll see that we have a panel 
summary(wy_data)


# dataset with a lot of missing values for 2019.
sum(is.na(wy_data))
  # 66 missing values



#Tidyverse is super powerful, and there is a lot to offer, learn more at:  https://tidyverse.tidyverse.org
# There's a few ways to deal with this
      # Drop all 2019 values
library(dplyr)
drop_2019<-wy_data%>%
  filter(Year != 2019)

#if you were only going to keep one year, 
keep_2019 <- wy_data %>% filter(Year == 2019)

      # Omit all rows with NA's
          # this will remove a lot of data if our NA's are more
          # scattered than in this dataset
omit_nas<-na.omit(wy_data)

      # Change NA's to a value
wy_data[is.na(wy_data)] <- 10
  # this doesn't work. Why?
      # because 'income' and 'population' are read in as strings, 
      # instead of numerics, let's fix that
wy_data2<-wy_data%>%
  mutate(inc=as.numeric(inc))%>%
  mutate(pop=as.numeric(pop))
      # whoa nellie, if we look at the data, we'll see that this
      # just replaced inc and pop with na's
          # why? you have to look closely, but it's because our data
          # used commas, so R can't turn it into a numeric
      # replace commas with nothing
wy_data2$inc<-gsub(",","",wy_data$inc)
wy_data2$pop<-gsub(",","",wy_data$pop)
  
  # try again to make numerics
wy_data2<-wy_data2%>%
  mutate(inc=as.numeric(inc))%>%
  mutate(pop=as.numeric(pop))

  # try again to replace na's with 10
wy_data2[is.na(wy_data)] <- 10

  # great, except that we probably don't actually want to replace 
  # NA's with 10, let's drop 2019 from that (since we still want
  # income and population as numerics)

wy_data2<-wy_data2%>%
  filter(Year != 2019) %>%
  mutate(inc_thousands = inc/1000)%>% # also make population and
  mutate(pop_thousands =pop/1000) # income in millions (it was
                                  # already in thousands)

# Regressions
# The data we have is a panel dataset, to make it easier to plot 
# and understand, let's only use the data for Albany County
albany<-wy_data2%>%
  filter(County=="Albany")

# Now that we've cleaned the data, we can make a regression...
reg<-lm(inc~us_gdp+Year, albany)
      # y variable ~ independent variable + independent variable ...
# take a look at the results
summary(reg)
plot(reg)

# save residuals and fitted values to the dataframe for one county
albany <-albany%>%
  mutate(resid=residuals(reg))%>%
  mutate(fit=fitted(reg))

# and make a simple time seriesplot
library(ggplot2)
ggplot(albany)+
  geom_point(aes(Year, inc/1000))+
  geom_line(aes(Year, fit/1000), linetype="dashed")+
  labs(y="Total Income (millions)", title="Albany County Incomes Over Time")+
  theme_classic()

# plot the residuals 
ggplot(albany)+
  geom_line(aes(Year, resid))+
  geom_line(aes(Year, 0), linetype="dashed")+
  labs(y="Residuals", title="Residuals of regression")+
  theme_classic()


# Let's go back to the panel dataset and make an awesome map
# except we won't use it as a panel, for simplicity, filter for
# only 2012
wy_2012<-wy_data2%>%
  filter(Year==2012)

# There are lots of map-making packages, but most are gigantic
# For our purposes, let's just use 'maps' and 'mapdata'
# 'maps' provides the map and 'mapdata' turns it into a dataframe to plot with ggplot2
library(mapdata)
library(maps)
wy<-map_data("state", region="wyoming")
county<- map_data("county", region = "wyoming")

ggplot()+
  geom_polygon(data=wy, aes(x=long, y=lat, group=group),
               fill=NA, color="black")+
  geom_polygon(data=county, aes(x=long, y=lat, group=group), 
               fill=NA, color="black")+
  theme_void()

# All that we're doing to make a map is using geom_polygon to make
# different polygons using latitude and longitude 
# the only thing that's really different and important is 
# group=group so that ggplot knows which points to connect

# now we will merge this with our existing dataframe
new_df<-merge(county, wy_2012, by="County", all=TRUE)
    # of course, this doesn't work because our dataframes have
    # different names for "County"

# change 'county' dataframe's column name (it's 'subregion')
colnames(county)[6]<-"County"

# also change our original county names to have a lower case first 
# letter and no underscore between words (Big_horn to big horn)
wy_2012$County<-tolower(wy_2012$County)
wy_2012$County<-gsub("_"," ",wy_2012$County)

# and merge them again 
new_df<-merge(county, wy_2012, by="County", all=TRUE)

# now try plotting where the county's fill is income
ggplot()+
  geom_polygon(data=wy, aes(x=long, y=lat, group=group),
               fill=NA, color="black")+
  geom_polygon(data=new_df, aes(x=long, y=lat, 
              group=group, fill=inc_thousands), color="black")+
  theme_void()

# what if we needed to merge the data to get FIPS codes?

countyFIPS <-read.csv("Wyoming_counties.csv", skip=0, header=FALSE, 
                      na.strings=c("","NA"), stringsAsFactors = FALSE)

# this is a mess, time to use stringr
library(stringr)
countyFIPS <- as.data.frame(str_split_fixed(countyFIPS[,c(1)], " ", 6))
countyFIPS <- countyFIPS[,-c(2,4:6)]
colnames(countyFIPS) <- c("County", "FIPS")

countyFIPS <- countyFIPS %>%
    mutate(County = as.character(County)) %>%
    mutate(FIPS = as.character(FIPS))

#suppose you don't need the state code (first 2 digits)
countyFIPS$FIPS <- str_sub(countyFIPS$FIPS, start = 3L)

#merge and be happy
wy_data2 <- merge(wy_data2, countyFIPS)

test <- merge(wy_2012, countyFIPS)

# And that's it! Happy coding!!!
